pub fn start_server(
embedder: EmbedderProxy,
mem_profiler_chan: ProfilerChan,
) -> Sender<DevtoolsControlMsg>Expand description
Spin up a devtools server that listens for connections on the specified port.
pub fn start_server(
embedder: EmbedderProxy,
mem_profiler_chan: ProfilerChan,
) -> Sender<DevtoolsControlMsg>Spin up a devtools server that listens for connections on the specified port.